==> qmmp-0.12.14.tar.bz2: qmmp-0.12.14/src/plugins/Output/wasapi/translations/wasapi_plugin_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sk">
<context>
    <name>OutputWASAPIFactory</name>
    <message>
        <location filename="../outputwasapifactory.cpp" line="30"/>
        <source>WASAPI Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputwasapifactory.cpp" line="55"/>
        <source>About WASAPI Output Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputwasapifactory.cpp" line="56"/>
        <source>Qmmp WASAPI Output Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputwasapifactory.cpp" line="57"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>WASAPI Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Device:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="68"/>
        <source>Exclusive mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="58"/>
        <source>Default</source>
        <translation>Predvolené</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/Output/wasapi/translations/wasapi_plugin_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sk_SK">
<context>
    <name>OutputWASAPIFactory</name>
    <message>
        <location filename="../outputwasapifactory.cpp" line="30"/>
        <source>WASAPI Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputwasapifactory.cpp" line="55"/>
        <source>About WASAPI Output Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputwasapifactory.cpp" line="56"/>
        <source>Qmmp WASAPI Output Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputwasapifactory.cpp" line="57"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>WASAPI Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="52"/>
        <source>Device:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="56"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
